@@ -11,20 +11,20 @@ gboolean libvk_init(gchar* proxy_host, gint proxy_port, gchar* account_name)
     char* error;
     handle = dlopen(LIB_PATH, RTLD_LAZY);
     if (!handle) {
-        g_print("dlopen_error: %s", dlerror());
+        msa_print("dlopen_error: %s", dlerror());
         ULOG_ERR_L("dlopen_error: %s", dlerror());
         return  FALSE;
     }
 
     if ((driver_module = malloc(sizeof(struct msa_module))) == NULL) {
-	g_print("memmory allocation error");
+	msa_print("memmory allocation error");
         ULOG_ERR_L("memmory allocation error");
         return FALSE;
     }
     *(void ** )(&driver_init) = dlsym(handle, MODULE_INIT);
 
     if ((error = dlerror()) != NULL || driver_init == NULL) {
-        g_print("dlsym_error: %s", error);
+        msa_print("dlsym_error: %s", error);
         ULOG_ERR_L("dlsym_error: %s", error);
         dlclose(handle);
         return FALSE;
@@ -41,6 +41,11 @@ gboolean libvk_init(gchar* proxy_host, gint proxy_port, gchar* account_name)
     return TRUE;
 }
 
+void libvk_uninit()
+{
+    driver_module->shutdown(driver_module);
+}
+
 void libvk_set_settings(gchar *params)
 {
     g_debug("%s:%d: Call nd_set_settings()", __FILE__, __LINE__);
@@ -72,7 +77,7 @@ gboolean libvk_get_settings(SharingAccount* account)
 {
     int ret = TRUE;
 
-    g_print("%s:%d: Call nd_get_settings()", __FILE__, __LINE__);
+    msa_print("%s:%d: Call nd_get_settings()", __FILE__, __LINE__);
     xmlChar *req_string = (xmlChar*)g_strconcat("<?xml version=\"1.0\"?>",
     "<TransitData>\
 <SourceID>", driver_module->id, "</SourceID>\
@@ -115,10 +120,10 @@ gboolean libvk_get_settings(SharingAccount* account)
 
 gboolean libvk_testConnection()
 {
-    g_print("Function start okey\n");
-    gboolean ret_val = FALSE;
+    msa_print("Function start okey\n");
+    gboolean ret_val = TRUE;
 
-    g_print("%s:%d: Call testConnection()\n", __FILE__, __LINE__);
+    msa_print("%s:%d: Call testConnection()\n", __FILE__, __LINE__);
     xmlChar *req_string = (xmlChar*)g_strconcat("<?xml version=\"1.0\"?>",
     "<TransitData>\
     <SourceID>", driver_module->id, "</SourceID>\
@@ -138,14 +143,14 @@ gboolean libvk_testConnection()
 
     xmlDocDump(stdout, resp);
 
-    xmlNodePtr node = xpath_get_node(XPATH_GET_ERRCODE, resp);
+    xmlNodePtr node = xpath_get_node(XPATH_GET_FUNCTION, resp);
     gchar* resp_code = (gchar*)xmlNodeGetContent(node);
     
-    g_printf("%s:%d:%s: resp_code=%s\n", __FILE__, __LINE__, __FUNCTION__, resp_code);
+    msa_print("%s:%d:%s: resp_code=%s\n", __FILE__, __LINE__, __FUNCTION__, resp_code);
     
     // FIXME разобрать коды ошибок более детально!
-    if(g_strcmp0(resp_code, DRV_AUTH_SUCCESS_CODE) == 0) {
-        ret_val = TRUE;
+    if(g_strcmp0(resp_code, ERROR_MESSAGE) == 0) {
+        ret_val = FALSE;
     }
 
     xmlFreeDoc(resp);
@@ -228,10 +233,10 @@ void libvk_getHash()
     libvk_getAlbums(&list_albums);
 }
 
-void libvk_uploadPhoto(gchar *aid, gchar *file, gchar *file_name)
+gboolean libvk_uploadPhoto(gchar *aid, gchar *file, gchar *file_name)
 {
 
-    g_printf("Start init %s %d\n", driver_module->proxy, driver_module->port);
+    msa_print("Start init %s %d\n", driver_module->proxy, driver_module->port);
 
     g_debug("%s:%d: Call nd_uploadPhoto()", __FILE__, __LINE__);
     xmlChar *req_string = (xmlChar*)g_strconcat("<?xml version=\"1.0\"?>",
@@ -254,9 +259,25 @@ void libvk_uploadPhoto(gchar *aid, gchar *file, gchar *file_name)
     /* process request */
     driver_module->send(req, &resp, driver_module);
 
+    gboolean ret_val = TRUE;
+
+    xmlNodePtr node = xpath_get_node(XPATH_GET_FUNCTION, resp);
+    gchar* resp_code = (gchar*)xmlNodeGetContent(node);
+
+    msa_print("%s:%d:%s: resp_code=%s\n", __FILE__, __LINE__, __FUNCTION__, resp_code);
+
+    // FIXME разобрать коды ошибок более детально!
+    if(g_strcmp0(resp_code, ERROR_MESSAGE) == 0) {
+        ret_val = FALSE;
+    }
+
+    g_free(resp_code);
+
     xmlDocDump(stdout, resp);
     g_free(req_string);
     xmlFreeDoc(resp);
+
+    return ret_val;
 }
 
 /**
