@@ -155,16 +155,11 @@ sharing_plugin_interface_update_options (SharingAccount *account,
 
     gboolean ret = FALSE;
     GSList *list_albums = NULL;
-    
-    #ifdef TABLET
+
     const gchar* proxy_host = con_ic_connection_get_proxy_host(con,
                         CON_IC_PROXY_PROTOCOL_HTTP);
     gint proxy_port = con_ic_connection_get_proxy_port(con,
                         CON_IC_PROXY_PROTOCOL_HTTP);
-    #else
-    gchar* proxy_host = "proxy.karelia.ru";// = g_strdup("10.10.99.26");
-    gint proxy_port = 81;// = 8345;
-    #endif
 
     gchar* account_name = sharing_account_get_username (account);
 
@@ -187,8 +182,8 @@ sharing_plugin_interface_update_options (SharingAccount *account,
 
     if (ret == TRUE) {
         libvk_get_settings (account);
-        libvk_uninit();
     }
+    libvk_uninit();
     
     /* Callback */
     void (*fp) (SharingPluginInterfaceUpdateOptionsResult, gpointer);
