@@ -19,14 +19,6 @@
 //#include "common.h"
 #include "libvkontakte_interface.h"
 
-#define HTTP_LOGIN_SUCCSESS 200
-#define HTTP_LOGIN_FAILED 302
-
-
-#ifdef __ARMEL__
-#define TABLET
-#endif
-
 /**
  * test:
  * @account: #SharingAccount to be tested
@@ -43,16 +35,10 @@ SharingPluginInterfaceAccountValidateResult validate (SharingAccount* account,
     SharingPluginInterfaceAccountValidateResult ret =
         SHARING_ACCOUNT_VALIDATE_SUCCESS;
     
-    #ifdef TABLET
     const gchar* proxy_host = con_ic_connection_get_proxy_host(con,
                         CON_IC_PROXY_PROTOCOL_HTTP);
     gint proxy_port = con_ic_connection_get_proxy_port(con,
                         CON_IC_PROXY_PROTOCOL_HTTP);
-    printf("proxy settings host=%s port=%d\n", proxy_host, proxy_port);
-    #else
-    gchar* proxy_host = "proxy.karelia.ru"; //g_strdup("10.10.99.26");
-    gint proxy_port = 81; //8345;
-    #endif
 
     gchar* account_name = sharing_account_get_username (account);
 
